@@ -33,9 +33,10 @@
 #  define KNOTIFICATIONS_DEPRECATED_NO_EXPORT KNOTIFICATIONS_NO_EXPORT KNOTIFICATIONS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KNOTIFICATIONS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KNOTIFICATIONS_NO_DEPRECATED
+#    define KNOTIFICATIONS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
